@@ -226,6 +226,8 @@ class NetBoxInventory:
 
         devices: List[Dict[str, Any]] = []
         devices_dict = {}
+        #print("A URL e:", url)
+        #print("Os params sao:", params)
 
         while url:
             if params:
@@ -239,34 +241,52 @@ class NetBoxInventory:
                 )
 
             resp = r.json()
+            #print("A resposta em JSON e: ", resp)
             circuits.extend(resp.get("results"))
 
             url = resp.get("next")
 
+        #print("Os circuitos sao: ", circuits)
         for circuit in circuits:
+            #print("O circuito e: ", circuit)
+            #print("O termination_a da API Circuitose: ", circuit["termination_a"])
+            #print("O termination_z da API Circuitos e: ", circuit["termination_z"])
             termination_a = self._get_resources(
                 url=f"{self.nb_url}/api/circuits/circuit-terminations/", params={"id": circuit["termination_a"]["id"]})
             termination_z = self._get_resources(
                 url=f"{self.nb_url}/api/circuits/circuit-terminations/", params={"id": circuit["termination_z"]["id"]})
+            
+            #print("O termination_a da API Circuito Terminations e: ", termination_a)
+            #print("O termination_z da API Circuito Terminations e: ", termination_z)
+            
+            try:
+                if termination_a:
+                    #print("O ID do dispositivo de terminacao a e: ", termination_a[0]["cable_peer"]["device"]["id"])
+                    device_a = self._get_resources(
+                        url=f"{self.nb_url}/api/dcim/devices", 
+                        params={"id": termination_a[0]["cable_peer"]["device"]["id"]}
+                    )
+                    if device_a:
+                        if device_a[0]["name"] in devices_dict:
+                            device = devices_dict.get(device_a[0]["name"])
+                            device["tags"].append(circuit["status"]["value"])
+                            devices_dict[device_a[0]["name"]] = device
+                        else:
+                            device_a[0]["tags"].append(
+                                circuit["status"]["value"])
+                            devices_dict[device_a[0]["name"]] = device_a[0]
 
-            if termination_a:
-                device_a = self._get_resources(
-                    url=f"{self.nb_url}/api/dcim/devices", params={"id": termination_a[0]["cable_peer"]["device"]["id"]})
-                if device_a:
-
-                    if device_a[0]["name"] in devices_dict:
-                        device = devices_dict.get(device_a[0]["name"])
-                        device["tags"].append(circuit["status"]["value"])
-                        devices_dict[device_a[0]["name"]] = device
-
-                    else:
-                        device_a[0]["tags"].append(
-                            circuit["status"]["value"])
-                        devices_dict[device_a[0]["name"]] = device_a[0]
-            if termination_z:
-                device_z = self._get_resources(
-                    url=f"{self.nb_url}/api/dcim/devices", params={"id": termination_z[0]["cable_peer"]["device"]["id"]})
-                if device_z:
-                    devices_dict[device_z[0]["name"]] = device_z[0]
+                if termination_z:
+                    #print("O ID do dispositivo de terminacao z e: ", termination_z[0]["cable_peer"]["device"]["id"])
+                    device_z = self._get_resources(
+                        url=f"{self.nb_url}/api/dcim/devices", 
+                        params={"id": termination_z[0]["cable_peer"]["device"]["id"]}
+                    )
+                    if device_z:
+                        devices_dict[device_z[0]["name"]] = device_z[0]
+            except TypeError:
+                # Case where circuit status is decomissioned and does not have peers anymore
+                #print("Circuito nao tem cable peers!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!")
+                continue
         devices = devices_dict.values()
         return devices
