@@ -118,16 +118,24 @@ class NetboxManager:
 
     def initInventory(self):
         # INVENTORY
+        # MUDANCA filter_parameters
+        options = {
+            "nb_url": self.nb_url,
+            "nb_token": self.nb_token,   
+        }
+        if not self.filter_parameters:
+            options["filter_parameters"] = self.filter_parameters
+
         self._nr = InitNornir(
             inventory={
                 "plugin": "NetBoxInventory",
-                "options": {
-                    "nb_url": self.nb_url,
-                    "nb_token": self.nb_token,
-                    "filter_parameters": self.filter_parameters
-                },
+                #"options": {
+                #    "nb_url": self.nb_url,
+                #    "nb_token": self.nb_token,
+                #    "filter_parameters": self.filter_parameters
+                #},
+                "options": options,
                 "transform_function": "validation_context_transfer_function" if self.context == "validation" else "master_context_transfer_function"
-
             }
         )
 
