@@ -20,10 +20,10 @@ def get_sot_filter_parameters():
 
 filter_params = get_sot_filter_parameters()
 
-#netbox_manager = NetboxManager(filter_params=filter_params)
+netbox_manager = NetboxManager(filter_params=filter_params)
 #############################################################################################################################################
 # TODO: testar sem filter parameters
-netbox_manager = NetboxManager()
+#netbox_manager = NetboxManager()
 
 nb_url = netbox_manager.nb_url
 filter_parameters = netbox_manager.filter_parameters
